# yassin-matrix

A lightweight Python library to multiply two matrices of any compatible size.

## Example

```python
from yassin_matrix import martices_multiplication

a = [[3, 2, 3], [7, 5, 6]]
b = [[79, 8], [0, 10], [1, 14]]

result = martices_multiplication(a, b)
print(result)
